@@ -1,4 +1,5 @@
 import attrs
+import decimal
 from ..core import Field
 from ..core.mixin import WithQualifiers
 from ..core.exceptions import FormatMismatchError
@@ -78,9 +79,11 @@ def integer_converter(value):
 
 
 def decimal_converter(value):
+    if isinstance(value, Decimal):
+        return value.value
     try:
-        return float(value)
-    except ValueError as e:
+        return decimal.Decimal(value)
+    except decimal.InvalidOperation as e:
         raise FormatMismatchError(str(e))
 
 
@@ -135,16 +138,25 @@ class Integer(Singluar, ScalarMixin):
     def __int__(self):
         return self.value
 
+    def __float__(self):
+        return float(self.value)
+
+    def __bool__(self):
+        return bool(self.value)
+
 
 @attrs.define
 class Decimal(Singluar, ScalarMixin):
 
-    value: float = attrs.field(converter=decimal_converter)
+    value: decimal.Decimal = attrs.field(converter=decimal_converter)
 
-    raw_type = int
+    raw_type = float
 
     def __float__(self):
-        return self.value
+        return float(self.value)
+
+    def __bool__(self):
+        return bool(self.value)
 
 
 @attrs.define
