@@ -44,9 +44,13 @@ class File(FsObject):
         fspath = self.select_by_ext()
         if not fspath.is_file():
             if not fspath.exists():
-                raise FileFormatsError(
+                msg = (
                     f"Selected fspath for {type(self)}, '{str(fspath)}', does not exist"
                 )
+                if fspath.parent.exists():
+                    neighbours = [p.name for p in fspath.parent.iterdir()]
+                    msg += f". Found neighbouring files {neighbours}"
+                raise FileFormatsError(msg)
             else:
                 msg = ", it is a directory" if fspath.is_dir() else ""
                 raise FormatMismatchError(
@@ -103,14 +107,15 @@ class File(FsObject):
     @property
     def actual_ext(self):
         "The actual file extension (out of the primary  and alternate extensions possible)"
-        try:
-            return next(e for e in self.possible_exts if self.fspath.name.endswith(e))
-        except StopIteration:
+        matching = [e for e in self.possible_exts if self.fspath.name.endswith(e)]
+        if not matching:
             assert False, (
                 f"extension of fspath {self.fspath} is not in possible extensions for "
                 f"{type(self)} class: {self.possible_exts}. This should have been "
                 "checked at initialisation"
             )
+        # Return the longest matching extension, useful for optional extensions
+        return sorted(matching, key=lambda x: len(x))[-1]
 
     @property
     def stem(self):
@@ -118,7 +123,7 @@ class File(FsObject):
 
 
 @attrs.define
-class BaseDirectory(FsObject):
+class Directory(FsObject):
     """Base directory to be overridden by subtypes that represent directories but don't
     want to inherit content type "qualifers" (i.e. most of them)"""
 
@@ -188,10 +193,51 @@ class BaseDirectory(FsObject):
         return super().hash_files(relative_to=relative_to, **kwargs)
 
 
-class Directory(WithQualifiers, BaseDirectory):
-    """Generic directory, which can be qualified by the formats of its contents"""
+class TypedSet(FileSet):
+    """List of specific file types (similar to the contents of a directory but not
+    enclosed in one)"""
+
+    content_types = ()
+
+    @property
+    def contents(self):
+        for content_type in self.content_types:
+            for p in self.fspaths:
+                try:
+                    yield content_type([p])
+                except FormatMismatchError:
+                    continue
+
+    @mark.check
+    def validate_contents(self):
+        if not self.content_types:
+            return
+        not_found = set(self.content_types)
+        for fspath in self.fspaths:
+            for content_type in list(not_found):
+                if content_type.matches(fspath):
+                    not_found.remove(content_type)
+                    if not not_found:
+                        return
+        assert not_found
+        raise FormatMismatchError(
+            f"Did not find the required content types, {not_found}, within the "
+            f"given list {self.fspaths}"
+        )
+
+
+class DirectoryContaining(WithQualifiers, Directory):
+    """Generic directory qualified by the formats of its contents"""
 
     # WithQualifiers-required class attrs
     qualifiers_attr_name = "content_types"
     allowed_qualifiers = (FileSet,)
-    generically_qualified = True
+    generically_qualifies = True
+
+
+class SetOf(WithQualifiers, TypedSet):
+
+    # WithQualifiers-required class attrs
+    qualifiers_attr_name = "content_types"
+    allowed_qualifiers = (FileSet,)
+    generically_qualifies = True
